@@ -97,10 +97,9 @@ class Domoticz(IPlugin):
 				resp = requests.get ('http://192.168.0.3:8080/json.htm?type=devices&filter=temp&used=true&order=Name')
 				jsonreq = resp.json()
 #				log.msg("resp  :  %s" % (req))				
-				log.msg("resp  :  %s" % (resp))
-				log.msg("response   :  %s" % (jsonreq))
-				log.msg("*********************************************  : ")
-				log.msg("jsonreq.result :  %s" % (jsonreq['result']))
+#				log.msg("response   :  %s" % (jsonreq))
+#				log.msg("*********************************************  : ")
+#				log.msg("jsonreq.result :  %s" % (jsonreq['result']))
 				for rt in jsonreq['result'] :
 					log.msg(" jsonreq - idx   :  %s" % (rt['idx']))
 					log.msg("   jsonreq - type   :  %s" % (rt['Type']))
